@@ -64,7 +64,7 @@
 #'
 #' cor_test(iris, "Sepal.Length", "Sepal.Width")
 #' cor_test(iris, "Sepal.Length", "Sepal.Width", method = "spearman")
-#' \dontrun{
+#' \donttest{
 #' cor_test(iris, "Sepal.Length", "Sepal.Width", method = "kendall")
 #' cor_test(iris, "Sepal.Length", "Sepal.Width", method = "biweight")
 #' cor_test(iris, "Sepal.Length", "Sepal.Width", method = "distance")
@@ -112,8 +112,12 @@
 #'
 #' # Partial
 #' cor_test(iris, "Sepal.Length", "Sepal.Width", partial = TRUE)
-#' cor_test(iris, "Sepal.Length", "Sepal.Width", multilevel = TRUE)
-#' cor_test(iris, "Sepal.Length", "Sepal.Width", partial_bayesian = TRUE)
+#' if (require("lme4", quietly = TRUE)) {
+#'   cor_test(iris, "Sepal.Length", "Sepal.Width", multilevel = TRUE)
+#' }
+#' if (require("rstanarm", quietly = TRUE)) {
+#'   cor_test(iris, "Sepal.Length", "Sepal.Width", partial_bayesian = TRUE)
+#' }
 #' }
 #' @export
 cor_test <- function(data,
@@ -234,40 +238,38 @@ cor_test <- function(data,
     }
 
     # Bayesian
+  } else if (method %in% c("tetra", "tetrachoric")) {
+    insight::format_error("Tetrachoric Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
+  } else if (method %in% c("poly", "polychoric")) {
+    insight::format_error("Polychoric Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
+  } else if (method %in% c("biserial", "pointbiserial", "point-biserial")) {
+    insight::format_error("Biserial Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
+  } else if (method == "biweight") {
+    insight::format_error("Biweight Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
+  } else if (method == "distance") {
+    insight::format_error("Bayesian distance correlations are not supported yet. Get in touch if you want to contribute.")
+  } else if (method %in% c("percentage", "percentage_bend", "percentagebend", "pb")) {
+    insight::format_error("Bayesian Percentage Bend correlations are not supported yet. Get in touch if you want to contribute.")
+  } else if (method %in% c("blomqvist", "median", "medial")) {
+    insight::format_error("Bayesian Blomqvist correlations are not supported yet. Check-out the BBcor package (https://github.com/donaldRwilliams/BBcor).")
+  } else if (method == "hoeffding") {
+    insight::format_error("Bayesian Hoeffding's correlations are not supported yet. Check-out the BBcor package (https://github.com/donaldRwilliams/BBcor).")
+  } else if (method == "gamma") {
+    insight::format_error("Bayesian gamma correlations are not supported yet. Get in touch if you want to contribute.")
+  } else if (method %in% c("shepherd", "sheperd", "shepherdspi", "pi")) {
+    out <- .cor_test_shepherd(data, x, y, ci = ci, bayesian = TRUE, ...)
   } else {
-    if (method %in% c("tetra", "tetrachoric")) {
-      insight::format_error("Tetrachoric Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
-    } else if (method %in% c("poly", "polychoric")) {
-      insight::format_error("Polychoric Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
-    } else if (method %in% c("biserial", "pointbiserial", "point-biserial")) {
-      insight::format_error("Biserial Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
-    } else if (method == "biweight") {
-      insight::format_error("Biweight Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
-    } else if (method == "distance") {
-      insight::format_error("Bayesian distance correlations are not supported yet. Get in touch if you want to contribute.")
-    } else if (method %in% c("percentage", "percentage_bend", "percentagebend", "pb")) {
-      insight::format_error("Bayesian Percentage Bend correlations are not supported yet. Get in touch if you want to contribute.")
-    } else if (method %in% c("blomqvist", "median", "medial")) {
-      insight::format_error("Bayesian Blomqvist correlations are not supported yet. Check-out the BBcor package (https://github.com/donaldRwilliams/BBcor).")
-    } else if (method == "hoeffding") {
-      insight::format_error("Bayesian Hoeffding's correlations are not supported yet. Check-out the BBcor package (https://github.com/donaldRwilliams/BBcor).")
-    } else if (method == "gamma") {
-      insight::format_error("Bayesian gamma correlations are not supported yet. Get in touch if you want to contribute.")
-    } else if (method %in% c("shepherd", "sheperd", "shepherdspi", "pi")) {
-      out <- .cor_test_shepherd(data, x, y, ci = ci, bayesian = TRUE, ...)
-    } else {
-      out <- .cor_test_bayes(
-        data,
-        x,
-        y,
-        ci = ci,
-        method = method,
-        bayesian_prior = bayesian_prior,
-        bayesian_ci_method = bayesian_ci_method,
-        bayesian_test = bayesian_test,
-        ...
-      )
-    }
+    out <- .cor_test_bayes(
+      data,
+      x,
+      y,
+      ci = ci,
+      method = method,
+      bayesian_prior = bayesian_prior,
+      bayesian_ci_method = bayesian_ci_method,
+      bayesian_test = bayesian_test,
+      ...
+    )
   }
 
   # Replace by NANs if invalid
@@ -284,8 +286,11 @@ cor_test <- function(data,
 
   # Reorder columns
   if ("CI_low" %in% names(out)) {
-    order <- c("Parameter1", "Parameter2", "r", "rho", "tau", "Dxy", "CI", "CI_low", "CI_high")
-    out <- out[c(order[order %in% names(out)], setdiff(colnames(out), order[order %in% names(out)]))]
+    col_order <- c("Parameter1", "Parameter2", "r", "rho", "tau", "Dxy", "CI", "CI_low", "CI_high")
+    out <- out[c(
+      col_order[col_order %in% names(out)],
+      setdiff(colnames(out), col_order[col_order %in% names(out)])
+    )]
   }
 
   # Output
