@@ -17,7 +17,7 @@
     var_x <- datawizard::ranktransform(var_x, sign = TRUE, method = "average")
     var_y <- datawizard::ranktransform(var_y, sign = TRUE, method = "average")
     method <- "Bayesian Spearman"
-  } else if (tolower(method) %in% "gaussian") {
+  } else if (tolower(method) == "gaussian") {
     var_x <- stats::qnorm(rank(var_x) / (length(var_x) + 1))
     var_y <- stats::qnorm(rank(var_y) / (length(var_y) + 1))
     method <- "Bayesian Gaussian rank"
