@@ -3,21 +3,7 @@
   var_x <- .complete_variable_x(data, x, y)
   var_y <- .complete_variable_y(data, x, y)
 
-  if (!corrected) {
-    rez <- .cor_test_distance_raw(var_x, var_y, index = 1)
-    rez <- data.frame(
-      Parameter1 = x,
-      Parameter2 = y,
-      r = rez$r,
-      CI_low = NA,
-      CI_high = NA,
-      t = NA,
-      df_error = NA,
-      p = NA,
-      Method = "Distance",
-      stringsAsFactors = FALSE
-    )
-  } else {
+  if (corrected) {
     rez <- .cor_test_distance_corrected(var_x, var_y, ci = ci)
     rez <- data.frame(
       Parameter1 = x,
@@ -31,6 +17,20 @@
       Method = "Distance (Bias Corrected)",
       stringsAsFactors = FALSE
     )
+  } else {
+    rez <- .cor_test_distance_raw(var_x, var_y, index = 1)
+    rez <- data.frame(
+      Parameter1 = x,
+      Parameter2 = y,
+      r = rez$r,
+      CI_low = NA,
+      CI_high = NA,
+      t = NA,
+      df_error = NA,
+      p = NA,
+      Method = "Distance",
+      stringsAsFactors = FALSE
+    )
   }
 
   rez
@@ -60,14 +60,14 @@
   M <- n * (n - 3) / 2
   dof <- M - 1
 
-  t <- sqrt(M - 1) * r / sqrt(1 - r^2)
-  p <- 1 - stats::pt(t, df = dof)
+  tstat <- sqrt(M - 1) * r / sqrt(1 - r^2)
+  p <- 1 - stats::pt(tstat, df = dof)
 
   ci_vals <- cor_to_ci(r, n = n, ci = ci)
 
   list(
     r = r,
-    t = t,
+    t = tstat,
     df_error = dof,
     p = p,
     CI_low = ci_vals$CI_low,
@@ -91,16 +91,16 @@
   A <- .A_kl(x, index)
   B <- .A_kl(y, index)
 
-  cov <- sqrt(mean(A * B))
+  cov_ab <- sqrt(mean(A * B))
   dVarX <- sqrt(mean(A * A))
   dVarY <- sqrt(mean(B * B))
   V <- sqrt(dVarX * dVarY)
   if (V > 0) {
-    r <- cov / V
+    r <- cov_ab / V
   } else {
     r <- 0
   }
-  list(r = r, cov = cov)
+  list(r = r, cov = cov_ab)
 }
 
 
