@@ -1,6 +1,6 @@
 #' @keywords internal
 .clean_data <- function(data, include_factors = TRUE, multilevel = FALSE) {
-  if (multilevel == FALSE) {
+  if (!multilevel) {
     if (include_factors) {
       data <- datawizard::to_numeric(data)
     } else {
